import request from '@/utils/request'

// 查询属性列表
export function listDept(query) {
  return request({
    url: '/system/tBusGameAttribute/list',
    method: 'get',
    params: query
  })
}

// 查询属性列表（排除节点）
export function listDeptExcludeChild(gameId) {
  return request({
    url: '/system/tBusGameAttribute/list/exclude/' + gameId,
    method: 'get'
  })
}

// 查询属性详细
export function getDept(query) {
  return request({
    url: '/system/tBusGameAttribute/queryById',
    method: 'get',
	params: query
  })
}

// 新增属性
export function addDept(data) {
  return request({
    url: '/system/tBusGameAttribute/add',
    method: 'post',
    data: data
  })
}

// 修改属性
export function updateDept(data) {
  return request({
    url: '/system/tBusGameAttribute/edit',
    method: 'put',
    data: data
  })
}

// 删除属性
export function delDept(query) {
  return request({
    url: '/system/tBusGameAttribute/deleteById',
    method: 'delete',
	params: query
  })
}