<template>
	<div class="app-container">
		<el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch">
			<el-form-item label="属性名称" prop="attributeName">
				<el-input v-model="queryParams.attributeName" placeholder="请输入属性名称" clearable
					@keyup.enter.native="handleQuery" />
			</el-form-item>
			<el-form-item label="所属游戏" prop="gameId">
				<el-select v-model="queryParams.gameId" @change="handleQuery" style="width: 100%" filterable
					placeholder="请选择所属游戏">
					<el-option v-for="(item,index) in gameList" :key="item.id" :label="item.gameName"
						:value="item.id"></el-option>
				</el-select>
			</el-form-item>
			<el-form-item label="状态" prop="status">
				<el-select v-model="queryParams.status" placeholder="属性状态" clearable>
					<el-option v-for="dict in dict.type.sys_normal_disable" :key="dict.value" :label="dict.label"
						:value="dict.value" />
				</el-select>
			</el-form-item>
			<el-form-item>
				<el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
				<el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
			</el-form-item>
		</el-form>

		<el-row :gutter="10" class="mb8">
			<el-col :span="1.5">
				<el-button type="primary" plain icon="el-icon-plus" size="mini" @click="handleAdd"
					v-hasPermi="['system:dept:add']">新增</el-button>
			</el-col>
			<!-- <el-col :span="1.5">
				<el-button type="info" plain icon="el-icon-sort" size="mini" @click="toggleExpandAll">展开/折叠</el-button>
			</el-col> -->
			<right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
		</el-row>
		<!-- <el-tree :data="deptList" :props="defaultProps" @node-click="handleNodeClick"></el-tree> -->

		<el-table v-if="refreshTable" :data="deptList" row-key="gameId"
			:tree-props="{children: 'children', hasChildren: 'hasChildren'}">
			<el-table-column prop="id" label="属性id" width="260"></el-table-column>
			<el-table-column prop="attributeName" label="属性名称" width="260"></el-table-column>
			<el-table-column prop="orderNum" label="排序" width="200"></el-table-column>
			<el-table-column prop="status" label="状态" width="100">
				<template slot-scope="scope">
					<dict-tag :options="dict.type.sys_normal_disable" :value="scope.row.status" />
				</template>
			</el-table-column>
			<el-table-column label="创建时间" align="center" prop="createTime" width="200">
				<template slot-scope="scope">
					<span>{{ parseTime(scope.row.createTime) }}</span>
				</template>
			</el-table-column>
			<el-table-column label="操作" align="center" class-name="small-padding fixed-width">
				<template slot-scope="scope">
					<el-button size="mini" type="text" icon="el-icon-edit" @click="handleUpdate(scope.row)"
						v-hasPermi="['system:dept:edit']">修改</el-button>
					<el-button size="mini" type="text" icon="el-icon-plus" @click="handleAdd(scope.row)"
						v-hasPermi="['system:dept:add']">新增</el-button>
					<el-button v-if="scope.row.parentId != 0" size="mini" type="text" icon="el-icon-delete"
						@click="handleDelete(scope.row)" v-hasPermi="['system:dept:remove']">删除</el-button>
				</template>
			</el-table-column>
		</el-table>

		<!-- 添加或修改属性对话框 -->
		<el-dialog :title="title" :visible.sync="open" width="600px" append-to-body>
			<el-form ref="form" :model="form" :rules="rules" label-width="80px">
				<el-row>
					<el-col :span="24" v-if="form.parentId !== 0">
						<el-form-item label="上级属性" prop="parentId">
							<treeselect v-model="form.parentId" :options="deptOptions" :normalizer="normalizer"
								placeholder="选择上级属性" />
						</el-form-item>
					</el-col>
				</el-row>
				<el-row>
					<el-col :span="24">
						<el-form-item label="属性名称" prop="attributeName">
							<el-input type="textarea" v-model="form.attributeName" @input="qckg()"
								placeholder="请输入属性名称" />
						</el-form-item>
					</el-col>
				</el-row>
				<el-row>
					<el-col :span="24">
						<el-form-item label="显示排序" prop="orderNum">
							<el-input-number v-model="form.orderNum" controls-position="right" :min="0" />
						</el-form-item>
					</el-col>
				</el-row>
				<el-row>
					<el-col :span="12">
						<el-form-item label="类型" prop="type">
							<el-select v-model="form.type" placeholder="请选择">
								<el-option v-for="item in options" :key="item.value" :label="item.label"
									:value="item.value">
								</el-option>
							</el-select>
						</el-form-item>
					</el-col>
					<el-col :span="12">
						<el-form-item label="是否必填" prop="necessarily">
							<el-select v-model="form.necessarily" placeholder="请选择">
								<el-option v-for="item in options1" :key="item.value" :label="item.label"
									:value="item.value">
								</el-option>
							</el-select>
						</el-form-item>
					</el-col>
					<el-col :span="12">
						<el-form-item label="属性状态">
							<el-radio-group v-model="form.status">
								<el-radio v-for="dict in dict.type.sys_normal_disable" :key="dict.value"
									:label="dict.value">{{dict.label}}</el-radio>
							</el-radio-group>
						</el-form-item>
					</el-col>
				</el-row>
			</el-form>
			<div slot="footer" class="dialog-footer">
				<el-button type="primary" @click="submitForm">确 定</el-button>
				<el-button @click="cancel">取 消</el-button>
			</div>
		</el-dialog>
	</div>
</template>

<script>
	import {
		listDept,
		getDept,
		delDept,
		addDept,
		updateDept,
		listDeptExcludeChild
	} from "@/api/system/gameAttributes";
	import {
		getInitGoodsManager,
	} from "@/api/data/goods";
	import Treeselect from "@riophae/vue-treeselect";
	import "@riophae/vue-treeselect/dist/vue-treeselect.css";

	export default {
		name: "Dept",
		dicts: ['sys_normal_disable'],
		components: {
			Treeselect
		},
		data() {
			return {
				defaultProps: {
					children: 'children',
					label: 'label'
				},
				gameList: [],
				options: [{
					value: 0,
					label: '三级列表'
				}, {
					value: 1,
					label: '复选框'
				}, {
					value: 2,
					label: '单选框'
				}, {
					value: 3,
					label: '文本框'
				}, ],
				options1: [{
					value: 'true',
					label: '是'
				}, {
					value: 'false',
					label: '否'
				}, ],
				// 遮罩层
				loading: true,
				// 显示搜索条件
				showSearch: true,
				// 表格树数据
				deptList: [],
				// 属性树选项
				deptOptions: [],
				// 弹出层标题
				title: "",
				// 是否显示弹出层
				open: false,
				// 是否展开，默认全部展开
				isExpandAll: true,
				// 重新渲染表格状态
				refreshTable: true,
				// 查询参数
				queryParams: {
					deptName: undefined,
					status: undefined
				},
				// 对比数据
				dbData: {},
				dbData1: {},
				dataName: [],
				// 表单参数
				form: {},
				// 表单校验
				rules: {
					parentId: [{
						required: true,
						message: "上级属性不能为空",
						trigger: "blur"
					}],
					deptName: [{
						required: true,
						message: "属性名称不能为空",
						trigger: "blur"
					}],
					orderNum: [{
						required: true,
						message: "显示排序不能为空",
						trigger: "blur"
					}],
					email: [{
						type: "email",
						message: "请输入正确的邮箱地址",
						trigger: ["blur", "change"]
					}],
					phone: [{
						pattern: /^1[3|4|5|6|7|8|9][0-9]\d{8}$/,
						message: "请输入正确的手机号码",
						trigger: "blur"
					}]
				}
			};
		},
		created() {
			// this.getList();
			this.initGoodsManager()
		},
		methods: {
			qckg() {
				this.form.attributeName = this.form.attributeName.replace(/[\s'"[\]]/g, "");
				if(this.dbData1){
					const newArray1 = this.form.attributeName.split(",").filter(item => !this.dbData1.includes(item));
					this.form.attributeName=newArray1.join(',');
				}
				this.$forceUpdate();
			},
			initGoodsManager() {
				getInitGoodsManager().then(res => {
					this.gameList = res.gameList
				})
			},
			handleNodeClick(data) {
				console.log(data);
			},
			/** 查询属性列表 */
			getList() {
				this.loading = true;
				listDept(this.queryParams).then(response => {
					this.deptList = this.handleTree(response.data, "gameId");
					this.loading = false;
				});
			},
			/** 转换属性数据结构 */
			normalizer(node) {
				if (node.children && !node.children.length) {
					delete node.children;
				}
				return {
					id: node.gameId,
					label: node.attributeName,
					children: node.children
				};
			},
			// 取消按钮
			cancel() {
				this.open = false;
				this.reset();
			},
			// 表单重置
			reset() {
				this.form = {
					deptId: undefined,
					parentId: undefined,
					deptName: undefined,
					orderNum: undefined,
					leader: undefined,
					phone: undefined,
					email: undefined,
					status: "0"
				};
				this.resetForm("form");
			},
			/** 搜索按钮操作 */
			handleQuery() {
				this.getList();
			},
			/** 重置按钮操作 */
			resetQuery() {
				this.resetForm("queryForm");
				this.handleQuery();
			},
			/** 新增按钮操作 */
			handleAdd(row) {
				this.dbData = row.children;
				this.dbData.forEach(res => {
					this.dataName.push(res.attributeName)
				})
				let sxNames=this.dataName;
				this.dbData1 = sxNames.join('').replace(/[\s'"]/g, "");
				this.reset();
				if (row != undefined) {
					this.form.parentId = row.gameId;
				}
				this.open = true;
				this.title = "添加属性";
				listDept(this.queryParams).then(response => {
					this.deptOptions = this.handleTree(response.data, "gameId");
				});
			},
			/** 展开/折叠操作 */
			toggleExpandAll() {
				this.refreshTable = false;
				this.isExpandAll = !this.isExpandAll;
				this.$nextTick(() => {
					this.refreshTable = true;
				});
			},
			/** 修改按钮操作 */
			handleUpdate(row) {
				this.reset();
				let query = {
					id: row.id
				}
				getDept(query).then(response => {
					this.form = response.data;
					this.open = true;
					this.title = "修改属性";
				});
				listDeptExcludeChild(row.gameId).then(response => {
					this.deptOptions = this.handleTree(response.data, "gameId");
				});
			},
			/** 提交按钮 */
			submitForm: function() {
				this.$refs["form"].validate(valid => {
					if (valid) {
						if (this.form.gameId != undefined) {
							let query = {
								gameId: this.form.gameId,
								parentId: this.form.parentId,
								attributeName: this.form.attributeName,
								orderNum: this.form.orderNum,
								type: this.form.type,
								necessarily: this.form.necessarily,
								status: this.form.status,
								delFlag: '0'
							}
							updateDept(query).then(response => {
								this.$modal.msgSuccess("修改成功");
								this.open = false;
								this.getList();
								location.href = location.href + "#reloaded";
							});
						} else {
							this.form.delFlag == 0
							addDept(this.form).then(response => {
								this.$modal.msgSuccess("新增成功");
								this.dataName=[];
								this.open = false;
								this.getList();
							});
						}
					}
				});
			},
			/** 删除按钮操作 */
			handleDelete(row) {
				this.$modal.confirm('是否确认删除名称为"' + row.attributeName + '"的数据项？').then(function() {
					let query = {
						id: row.id
					}
					return delDept(query);
				}).then(() => {
					this.getList();
					this.$modal.msgSuccess("删除成功");
				}).catch(() => {});
			}
		}
	};
</script>